@@ -1,13 +1,13 @@
 package Text::YAWikiFormater;
 
-use 5.010;
+use 5.006;
 use strict;
 use warnings;
 
 use HTML::Entities qw(encode_entities);
 use JSON qw(from_json);
 
-our $VERSION = '0.51.0';
+our $VERSION = '0.50';
 
 my %plugins = (
     toc    => \&_handle_toc,
@@ -39,7 +39,7 @@ my %closed = (
     links    => [qr{(?=\[\[)}, qr{(?<=\]\])},\&_do_links],
     links2  => [qr{\s(?=http://)}, qr{\s},\&_do_links],
 
-    br    => [qr{^[\n\s]*(?=$)}msix, qr[$]msix, sub { "<br/><br/>",'',''}],
+    br    => [qr{^(?=$)}msix, qr[$]msix, sub { "<br/><br/>",'',''}],
 
     comments  => [qr{/\*}msix, qr{\*/}msix, sub{ '','',''}],
   );
@@ -48,9 +48,7 @@ my %nonclosed = (
     hr  => qr{^[-\*]{3,}\s*?$}msix,
   );
 
-my @do_first  = qw( code lists );
-# for consistent order
-my @do_second = qw( b i u del tt heads blockquote links links2 br comments );
+my @do_first = qw( code lists );
 
 sub new {
   my $class = shift;
@@ -68,7 +66,7 @@ sub urls {
 
   return unless $body;
 
-  my @links = $body =~m{(\[\[(?:[^\|\]]*)(?:\|(?:[^\]]+))?\]\])}g;
+  my @links = $body =~m{(\[\[(?:\S[^\|\]]*)(?:\|(?:[^\]]+))?\]\])}g;
   push @links, $body =~m{\s(https?://\S+)\s}g;
 
   my $links = $self->{_links} ||= {};
@@ -84,13 +82,11 @@ sub urls {
       next LINK;
     }
     
-    ($lnk) = $lnk =~ m{\A\[\[\s*(.*)\s*\]\]\z}g;
-		$lnk=~s{\s*\z}[]g;
-
-    my ($label,$link) = split qr{\s*\|\s*}, $lnk, 2;
+    ($lnk) = $lnk =~ m{\A\[\[(.*)\]\]\z}g;
+    my ($label,$link) = split qr{\|}, $lnk, 2;
     unless ($link) {
       $link = $label;
-      if ( $link =~ m{.*[\>\:]\s*([^\>]+)\z} ) {
+      if ( $link =~ m{.*[\>\:]([^\>]+)\z} ) {
         $label = $1;
       }
     }
@@ -128,7 +124,7 @@ sub urls {
     }
     
     if ( $categ ) {
-      $link =~ s{\s*\>\s*}{$categ}g;
+      $link =~ s{\>}{$categ}g;
     }
     if ( $base ) {
       $link = $base.$link;
@@ -146,7 +142,6 @@ sub urify {
   my $link = shift;
   my $reg = shift || "^\\w\\-\\/\\s\\#";
 
-	$link =~ s{\s*\z}{}g;
   $link =~ s{\s*>\s*}{/}g unless $link =~ m{/};
 
   $link = encode_entities( $link, $reg );
@@ -180,14 +175,12 @@ sub format {
 
   my %done = ();
 
-	$self->urls();
-
   $body =~ s{&}{&amp;}g;
   $body =~ s{<}{&lt;}g;
   $body =~ s{>}{&gt;}g;
 
   # closed tags
-  for my $tag ( @do_first, @do_second, keys %closed ) {
+  for my $tag ( @do_first, keys %closed ) {
     next if $done{ $tag }++;
 
     my ($re1, $re2, $re3, $re4, $re5, $re6)
@@ -213,9 +206,6 @@ sub format {
         } elsif (ref $re3 eq 'CODE') {
           ($t1,$in,$t2) = $re3->($self, $t1, $in, $t2);
         }
-				$t1 //= '';
-				$in //= '';
-				$t2 //= '';
         $re5 //= '';
         $body =~ s{$re1(.*?)$re2}{$t1$in$t2$re5}smxi;
       }
@@ -371,8 +361,6 @@ sub _do_links {
 
   my (undef, $link, undef) = @_;
 
-	$link =~s{\&gt;}[>]g;
-
   $self->urls() unless $self->{_links} and $self->{_links}->{$link};
 
   my $lnk = $self->{_links}->{$link} || {};
